'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-96af6326.js');
const index$1 = require('./index-4f18c0e2.js');

const stylesCss = ".sc-z-file-upload-h{display:flex;flex-direction:column;align-items:flex-start;color:var(--color-default-text);font-family:var(--font-family-sans);font-weight:var(--font-rg)}.sc-z-file-upload-h .modal-wrapper.sc-z-file-upload{display:flex;flex-direction:column;justify-content:center;padding:calc(var(--space-unit) * 2);row-gap:calc(var(--space-unit) * 2)}.sc-z-file-upload-h .modal-wrapper.sc-z-file-upload>.files-wrapper.sc-z-file-upload{display:flex;flex-direction:column;margin:calc(var(--space-unit) * 4);gap:var(--space-unit)}.sc-z-file-upload-h .text-container.sc-z-file-upload{display:flex;flex-direction:column;margin:auto;text-align:center}.sc-z-file-upload-h .text-container.sc-z-file-upload .upload-link.sc-z-file-upload{color:var(--color-text-link-blue);cursor:pointer;text-decoration:underline}.sc-z-file-upload-h .text-container.sc-z-file-upload .upload-link.sc-z-file-upload:focus-visible{box-shadow:var(--shadow-focus-primary);outline:none !important}.sc-z-file-upload-h .text-container.sc-z-file-upload .upload-link-text.sc-z-file-upload{margin-bottom:var(--space-unit)}.sc-z-file-upload-h input[type=\"file\"].sc-z-file-upload{display:none}.sc-z-file-upload-h #title.sc-z-file-upload+#description.sc-z-file-upload{margin-top:var(--space-unit)}.sc-z-file-upload-h>*.sc-z-file-upload+z-button.sc-z-file-upload,.sc-z-file-upload-h>.files-container.sc-z-file-upload+*.sc-z-file-upload,.sc-z-file-upload-h>.files-container.sc-z-file-upload:not(:first-child){margin-top:calc(var(--space-unit) * 3)}.sc-z-file-upload-h>.files-container.hidden.sc-z-file-upload{display:none}.sc-z-file-upload-h>.files-container.sc-z-file-upload>.uploaded-files-label.sc-z-file-upload{margin-bottom:calc(var(--space-unit) * 2)}.sc-z-file-upload-h>.files-container.sc-z-file-upload>.files-wrapper.sc-z-file-upload{display:flex;flex-wrap:wrap;column-gap:calc(var(--space-unit) * 2);row-gap:calc(var(--space-unit) * 2)}@media (min-width: 768px){.sc-z-file-upload-h>.container.sc-z-file-upload>z-button.sc-z-file-upload{align-self:flex-start}.sc-z-file-upload-h .modal-wrapper.sc-z-file-upload{padding:calc(var(--space-unit) * 3)}}@media (min-width: 1152px){.sc-z-file-upload-h .modal-wrapper.sc-z-file-upload{padding:calc(var(--space-unit) * 4)}}";
const ZFileUploadStyle0 = stylesCss;

const ZFileUpload = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.fileInput = index.createEvent(this, "fileInput", 7);
        this.fileError = index.createEvent(this, "fileError", 7);
        this.type = index$1.ZFileUploadType.DEFAULT;
        this.buttonVariant = undefined;
        this.acceptedFormat = undefined;
        this.fileMaxSize = undefined;
        this.mainTitle = undefined;
        this.description = undefined;
        this.uploadBtnLabel = "allega";
        this.dragAndDropLabel = "Rilascia i file in questa area per allegarli.";
        this.allowedFilesMessage = undefined;
        this.uploadClickableMessage = "Carica";
        this.uploadMessage = "o trascina dal tuo computer";
        this.errorModalTitle = "Errore di caricamento";
        this.errorModalMessage = undefined;
        this.uploadedFilesLabel = "File appena caricati";
        this.hasFileSection = true;
        this.inputName = "z-file-upload";
        this.showErrors = true;
        this._type = this.type;
        this.files = [];
        this.invalidFiles = new Map();
        this.input = undefined;
    }
    /** Listen `removeFile` event sent from z-file component */
    onFileRemoved(e) {
        this.removeFile(e.detail.fileName);
    }
    /** Listen fileDropped event sent from z-dragdrop-area component */
    fileDroppedListener(e) {
        this.input.files = e.detail;
        this.checkFilesValidity(this.input.files);
    }
    /** Get the list of uploaded files */
    async getFiles() {
        return this.files;
    }
    /** Remove a previously uploaded file */
    async removeFile(fileName) {
        const files = this.files;
        const index = files.findIndex((file) => file.name === fileName);
        if (index >= 0) {
            files.splice(index, 1);
            this.files = [...files];
        }
    }
    checkFilesValidity(files) {
        if (!files.length) {
            return;
        }
        Array.from(files).forEach((file) => {
            const fileSize = file.size / 1024 / 1024;
            const fileFormatOk = this.acceptedFormat
                .split(",")
                .some((ext) => file.name.toLowerCase().endsWith(ext.trim()));
            const fileSizeOk = fileSize <= this.fileMaxSize;
            if (fileSizeOk && fileFormatOk && !this.files.find((f) => f.name === file.name)) {
                this.files = [...this.files, file];
                this.fileInput.emit(file);
                this.input.value = "";
                return;
            }
            const sizeError = `Il file ${file.name} supera il limite di ${this.fileMaxSize}MB`;
            const formatError = `Il file ${file.name} ha un formato non supportato`;
            const errors = [
                !fileSizeOk && { cause: "size", message: sizeError },
                !fileFormatOk && { cause: "format", message: formatError },
            ].filter(Boolean);
            this.invalidFiles.set(file.name, errors);
            this.invalidFiles = new Map(this.invalidFiles); // trigger state update
            this.fileError.emit({ file: file.name, errors });
        });
    }
    resetErrors() {
        this.invalidFiles = new Map();
    }
    onFilesChange(e) {
        this.checkFilesValidity(e.target.files);
    }
    componentWillLoad() {
        // force default type on mobile and tablet viewport
        const mql = window.matchMedia("(max-width: 1151px)");
        this._type = mql.matches ? index$1.ZFileUploadType.DEFAULT : this.type;
        mql.addEventListener("change", (e) => {
            this._type = e.matches ? index$1.ZFileUploadType.DEFAULT : this.type;
        });
    }
    componentDidUpdate() {
        if (!this.showErrors || !this.invalidFiles.size) {
            return;
        }
        this.errorModal.open();
    }
    renderDescription(cssClass) {
        if (!this.description) {
            return;
        }
        return (index.h("span", { id: "description", class: cssClass }, this.description));
    }
    renderAllowedFilesMessage() {
        let fileFormatString = "";
        let fileWeightString = "";
        if (this.acceptedFormat) {
            const fileFormat = this.acceptedFormat
                .split(", ")
                .map((string) => string.substring(1).toUpperCase())
                .join(", ");
            fileFormatString = ` nei formati ${fileFormat}`;
        }
        if (this.fileMaxSize) {
            fileWeightString = ` per un massimo di ${this.fileMaxSize}MB di peso`;
        }
        const defaultMessage = fileFormatString || fileWeightString ? `Puoi allegare file${fileFormatString}${fileWeightString}.` : undefined;
        if (!this.allowedFilesMessage && !defaultMessage) {
            return;
        }
        return index.h("span", { class: "allowed-files-message body-3" }, this.allowedFilesMessage || defaultMessage);
    }
    renderFileSection() {
        if (!this.hasFileSection) {
            return;
        }
        return (index.h("section", { class: { "files-container": true, "hidden": !this.files.length } }, index.h("div", { class: "uploaded-files-label heading-3-sb" }, this.uploadedFilesLabel), index.h("div", { class: "files-wrapper" }, index.h("slot", { name: "files" }))));
    }
    renderInput() {
        return (index.h("input", { type: "file", name: this.inputName, multiple: true, onChange: (e) => this.onFilesChange(e), accept: this.acceptedFormat, ref: (val) => (this.input = val) }));
    }
    renderUploadButton() {
        return [
            index.h("z-button", { onClick: () => this.input.click(), onKeyPress: (e) => {
                    if (e.code == "Space" || e.code == "Enter") {
                        e.preventDefault();
                        this.input.click();
                    }
                }, id: "fileSelect", variant: this.buttonVariant, icon: "upload" }, this.uploadBtnLabel),
            this.renderInput(),
        ];
    }
    renderUploadLink() {
        return [
            this.renderInput(),
            index.h("span", { class: "body-1 upload-link-text" }, index.h("span", { tabIndex: 0, class: "body-1-sb upload-link", onClick: () => this.input.click(), onKeyPress: (e) => {
                    if (e.code == "Space" || e.code == "Enter") {
                        e.preventDefault();
                        this.input.click();
                    }
                } }, this.uploadClickableMessage), " ", this.uploadMessage),
        ];
    }
    renderDefaultMode() {
        return [
            this.renderDescription("body-3-sb"),
            this.renderAllowedFilesMessage(),
            this.renderFileSection(),
            this.renderUploadButton(),
        ];
    }
    renderDragDropMode() {
        return [
            this.renderFileSection(),
            index.h("z-dragdrop-area", { "drag-and-drop-label": this.dragAndDropLabel }, index.h("div", { class: "text-container" }, this.renderDescription("body-1"), this.renderUploadLink(), this.renderAllowedFilesMessage())),
        ];
    }
    renderFileErrors() {
        return Array.from(this.invalidFiles).map(([fileName, errors]) => {
            const prefix = `Il file ${fileName}`;
            return (index.h("span", { class: "error-message" }, "Il file ", index.h("span", { class: "body-3-sb" }, fileName), errors.map(({ message }) => message.replace(prefix, "")).join(" e "), "."));
        });
    }
    render() {
        return (index.h(index.Host, { key: '13ada780c37ca16c2153f8c1177864932fe299dd' }, this.mainTitle && (index.h("div", { key: 'dcf55ac93e6959136262d0422272ab4902c3cbed', id: "title", class: "heading-3-sb" }, this.mainTitle)), this._type == index$1.ZFileUploadType.DEFAULT ? this.renderDefaultMode() : this.renderDragDropMode(), !!this.invalidFiles.size && this.showErrors && (index.h("z-modal", { key: 'e7d8c001c513ab498779c752dc195ab03ec81a80', modalid: `file-upload-${this.type}-error-modal`, ref: (val) => (this.errorModal = val), modaltitle: this.errorModalTitle, onModalClose: () => this.resetErrors(), onModalBackgroundClick: () => this.resetErrors() }, index.h("div", { key: 'e5262f2f8b42dfe38ad4b794b08b4bf6b83b4a7a', slot: "modalContent" }, index.h("div", { key: '5e50b460de47813678ea1e2d3a2a3e0e76d0a6d0', class: "modal-wrapper body-3" }, this.errorModalMessage ? this.errorModalMessage : this.renderFileErrors()))))));
    }
    get host() { return index.getElement(this); }
};
ZFileUpload.style = ZFileUploadStyle0;

exports.z_file_upload = ZFileUpload;

//# sourceMappingURL=z-file-upload.cjs.entry.js.map