import { Host, h } from "@stencil/core";
import { BookCardVariant, ControlSize } from "../../../beans";
/**
 * @slot cta - top right cta (e.g. bookmark icon)
 * @slot ebook - as default, it shows laZ ebook link
 * @slot tags - tags section, default empty
 * @slot data - external link and pill, default empty
 * @slot apps - list of card-related apps, default empty
 * @slot coverOverlay - purple layer on top of book cover
 * @cssprop --z-book-card-portrait-cover-height - set custom cover height for portrait variant - default 378px
 * @cssprop --z-book-card-title-lines - set title avilable lines - default 2
 * @cssprop --z-book-card-title-word-break - set title word-break rule - default initial
 * @cssprop --z-book-card-subtitle-lines - set subtitle available lines - default 1
 * @cssprop --z-book-card-subtitle-word-break - set subtitle word-break rule - default break-all
 * @cssprop --z-book-card-authors-lines - set authors available lines - default 1
 * @cssprop --z-book-card-authors-word-break - set authors word-break rule - default break-all
 */
export class ZBookCard {
    constructor() {
        this.variant = BookCardVariant.PORTRAIT;
        this.cover = undefined;
        this.operaTitle = undefined;
        this.volumeTitle = undefined;
        this.authors = undefined;
        this.isbn = undefined;
        this.isbnLabel = "";
        this.year = undefined;
        this.ebookUrl = undefined;
        this.fallbackCover = undefined;
        this.titleHtmlTag = undefined;
    }
    emitEbookClick() {
        this.ebookClick.emit();
    }
    renderCover() {
        return (h("div", { class: "cover" }, h("img", { src: this.cover, onError: () => {
                if (this.fallbackCover) {
                    this.cover = this.fallbackCover;
                }
            }, "aria-hidden": "true" }), h("slot", { name: "coverOverlay" })));
    }
    renderYear() {
        if (!this.year) {
            return null;
        }
        return (h("div", { class: "year ellipsis body-4", "aria-description": "anno" }, this.year));
    }
    renderAuthors() {
        if (!this.authors) {
            return null;
        }
        return (h("div", { class: "cta-wrapper" }, h("div", { class: "authors ellipsis body-4", "aria-description": "autori" }, this.authors), this.variant === BookCardVariant.LANDSCAPE ? this.renderCtaSlot() : null));
    }
    renderOperaTitle() {
        const title = this.titleHtmlTag
            ? `<${this.titleHtmlTag}>${this.operaTitle}</${this.titleHtmlTag}>`
            : this.operaTitle;
        return (h("div", { class: "cta-wrapper" }, h("div", { class: "opera-title ellipsis body-2-sb", innerHTML: title }), this.variant === BookCardVariant.PORTRAIT ? this.renderCtaSlot() : null));
    }
    renderVolumeTitle() {
        if (!this.volumeTitle) {
            return null;
        }
        return h("div", { class: "volume-title ellipsis body-4" }, this.volumeTitle);
    }
    renderIsbn() {
        if (!this.isbn) {
            return null;
        }
        return (h("div", { class: "isbn ellipsis body-4-sb", "aria-description": `isbn ${this.isbnLabel}` }, this.isbn, " ", this.isbnLabel ? h("span", { class: "body-4" }, this.isbnLabel) : null));
    }
    renderEbook() {
        return (h("div", { class: "ebook" }, h("div", null, h("div", { class: "app-name" }, h("img", { class: "ebook-logo", "aria-hidden": "true" }), h("div", { class: "body-4-sb" }, "laZ Ebook"))), h("z-button", { size: ControlSize.X_SMALL, href: this.ebookUrl, target: "_blank", onClick: () => this.emitEbookClick(), htmlrole: "link", "aria-description": `leggi l'ebook ${this.operaTitle} su laZ Ebook` }, "leggi ebook")));
    }
    renderCtaSlot() {
        return h("slot", { name: "cta" });
    }
    render() {
        return (h(Host, { key: '239ba8bd3f52288ec3f748311dce284d71106ba0' }, h("div", { key: 'd25b33181914ddd8ff5f699cf02112237e2bf6e3', class: "main-content" }, this.renderCover(), h("div", { key: 'fa79e463b770b63f1f8a0bbde3f05105dc229344', class: "card-info" }, h("div", { key: '7e595f41169cca9455dc53b99ddc15342eb1b963', class: "top" }, h("div", { key: 'f9fe00fb63360154f451de3486385cf88202d107' }, this.renderYear(), this.renderAuthors(), this.renderOperaTitle(), this.renderVolumeTitle(), this.renderIsbn()), h("slot", { key: '2585df52a10a90cc2c10466a02fe4601ce015749', name: "tags" }), h("slot", { key: 'b383f55e1c64ce5c7578aa16eb68893f73c7c778', name: "data" })), h("slot", { key: '5cbbbc32f7142a6f2a8637ec220c3add460f3313', name: "ebook" }, !!this.ebookUrl && h("div", { key: '4aeb1dd60f20e6b50cd1459a933bd3e5a36112e4', class: "bottom" }, this.renderEbook())))), h("slot", { key: '78149851420a6e915b4fbebd95df89e45c56bc57', name: "apps" })));
    }
    static get is() { return "z-book-card"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["styles.css", "../../../tokens/typography.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["styles.css", "../../../tokens/typography.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "BookCardVariant",
                    "resolved": "BookCardVariant.LANDSCAPE | BookCardVariant.PORTRAIT",
                    "references": {
                        "BookCardVariant": {
                            "location": "import",
                            "path": "../../../beans",
                            "id": "src/beans/index.tsx::BookCardVariant"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Card variant: landscape, portrait"
                },
                "attribute": "variant",
                "reflect": true,
                "defaultValue": "BookCardVariant.PORTRAIT"
            },
            "cover": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Cover URL"
                },
                "attribute": "cover",
                "reflect": false
            },
            "operaTitle": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Opera title (card title)"
                },
                "attribute": "opera-title",
                "reflect": false
            },
            "volumeTitle": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Volume title (card subvolume)"
                },
                "attribute": "volume-title",
                "reflect": false
            },
            "authors": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Authors"
                },
                "attribute": "authors",
                "reflect": false
            },
            "isbn": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Main ISBN"
                },
                "attribute": "isbn",
                "reflect": false
            },
            "isbnLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "[optional] ISBN label"
                },
                "attribute": "isbn-label",
                "reflect": false,
                "defaultValue": "\"\""
            },
            "year": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] year"
                },
                "attribute": "year",
                "reflect": false
            },
            "ebookUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Show link to the ebook resource"
                },
                "attribute": "ebook-url",
                "reflect": false
            },
            "fallbackCover": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Fallback cover URL"
                },
                "attribute": "fallback-cover",
                "reflect": false
            },
            "titleHtmlTag": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "[optional] Set a specific h level as html tag for opera title"
                },
                "attribute": "title-html-tag",
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "ebookClick",
                "name": "ebookClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "click on ebook link"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=index.js.map
