import { Host, h } from "@stencil/core";
import { KeyboardCode } from "../../../beans";
export class ZTreeList {
    constructor() {
        this.parsedItems = [];
        this.items = [];
        this.htmlAriaLabelledby = undefined;
        this.htmlSectionTitle = undefined;
    }
    watchItems() {
        this.parsedItems = typeof this.items === "string" ? JSON.parse(this.items) : this.items;
    }
    componentWillLoad() {
        this.watchItems();
    }
    handleClick(item) {
        this.treeItemClicked.emit({ id: item.id, name: item.name, url: item.url });
    }
    getFocusableElements() {
        return Array.from(this.host.shadowRoot.querySelectorAll('a[tabindex="0"]'));
    }
    getAncestor(element, levels) {
        let ancestor = element;
        for (let i = 0; i < levels; i++) {
            ancestor = ancestor === null || ancestor === void 0 ? void 0 : ancestor.parentElement;
            if (!ancestor) {
                return;
            }
        }
        return ancestor;
    }
    handleArrowNav(event) {
        if (event.code === KeyboardCode.TAB) {
            event.preventDefault();
            return;
        }
        const focusableElements = this.getFocusableElements();
        const currentIndex = focusableElements.indexOf(event.target);
        if (currentIndex === -1) {
            return;
        }
        if (event.code === KeyboardCode.ARROW_DOWN || event.code === KeyboardCode.ARROW_UP) {
            event.preventDefault();
            const nextIndex = currentIndex + (event.code === KeyboardCode.ARROW_DOWN ? 1 : -1);
            if (nextIndex < 0 || nextIndex >= focusableElements.length) {
                return;
            }
            focusableElements[nextIndex].focus();
        }
        if (event.code === KeyboardCode.ARROW_LEFT) {
            event.preventDefault();
            const ancestor = this.getAncestor(focusableElements[currentIndex], 4);
            if (!ancestor ||
                !ancestor.children[0] ||
                (ancestor.children[0].tagName.toLowerCase() !== "a" && ancestor.getAttribute("tabindex") === null)) {
                return;
            }
            ancestor.children[0].focus();
        }
        if (event.code === KeyboardCode.ARROW_RIGHT) {
            event.preventDefault();
            const parentElm = event.target.closest("z-list-element");
            if (!parentElm) {
                return;
            }
            const childrenContainer = parentElm.querySelector("z-list");
            if (!childrenContainer) {
                return;
            }
            const firstChild = childrenContainer.querySelector('a[tabindex="0"]');
            if (!firstChild) {
                return;
            }
            firstChild.focus();
        }
    }
    renderTreeList(item, key, level = 1) {
        var _a, _b;
        this.htmlTag = item.url ? "a" : "span";
        const treeListContent = (h("z-list-element", { id: key, class: !item.icon ? "no-icon-elm" : "", clickable: Boolean(item.url), hasTreeItems: true, role: "none", "aria-hidden": undefined }, h(this.htmlTag, { class: {
                "list-element": true,
                "z-link": Boolean(item.url),
                "link-clickable": Boolean(item.url),
            }, tabIndex: item.url ? 0 : -1, onClick: () => this.handleClick(item), onKeyUp: (event) => {
                if (event.code === KeyboardCode.ENTER || event.code === KeyboardCode.SPACE) {
                    this.handleClick(item);
                }
            }, onKeyDown: (event) => this.handleArrowNav(event), role: item.url ? "treeitem" : undefined, "aria-hidden": item.url ? undefined : "true", "aria-expanded": ((_a = item.children) === null || _a === void 0 ? void 0 : _a.length) > 0 && true, "aria-level": level, "aria-label": item.name, href: item.url }, h("span", { class: "item ellipsis" }, item.icon && (h("z-icon", { width: 16, height: 16, fill: item.url ? "color-primary01" : "color-default-icon", class: "item-icon", name: item.icon })), h("span", { class: {
                "item-label": true,
                "no-icon-label": !item.icon,
                "bold-item": item.bold,
            }, title: item.name }, item.name))), ((_b = item.children) === null || _b === void 0 ? void 0 : _b.length) > 0 && (h("z-list", { role: "group" }, h("div", { class: "children-node" }, item.children.map((child, key) => this.renderTreeList(child, `${key}`, level + 1)))))));
        return treeListContent;
    }
    render() {
        const hasClickableItems = this.parsedItems.some((item) => !!item.url);
        return (h(Host, { key: '860eebd2ba1f46fb493bc07eb245596a9dc8be99', class: "tree-list", role: hasClickableItems ? "navigation" : "none", "aria-hidden": hasClickableItems ? undefined : "true", "aria-labelledby": this.htmlAriaLabelledby }, h("div", { key: '6a5876f627d499e9c04464383463f97d5caa1272', tabIndex: -1, role: hasClickableItems ? "tree" : "none", "aria-hidden": hasClickableItems ? undefined : "true", "aria-label": this.htmlSectionTitle }, this.parsedItems.map((item, key) => this.renderTreeList(item, `${key}`)))));
    }
    static get is() { return "z-tree-list"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["styles.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["styles.css"]
        };
    }
    static get properties() {
        return {
            "items": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "TreeListItem[] | string",
                    "resolved": "TreeListItem[] | string",
                    "references": {
                        "TreeListItem": {
                            "location": "import",
                            "path": "../../../beans",
                            "id": "src/beans/index.tsx::TreeListItem"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Items to render, if they have the url property they will be rendered as clickable links"
                },
                "attribute": "items",
                "reflect": false,
                "defaultValue": "[]"
            },
            "htmlAriaLabelledby": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Used for aria-labelledby attribute, sets name in \"navigation\""
                },
                "attribute": "html-aria-labelledby",
                "reflect": true
            },
            "htmlSectionTitle": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Used for aria-label attribute, sets name in \"tree\""
                },
                "attribute": "html-section-title",
                "reflect": true
            }
        };
    }
    static get events() {
        return [{
                "method": "treeItemClicked",
                "name": "treeItemClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emitted on item click, it return the id, name and url of the clicked item"
                },
                "complexType": {
                    "original": "{id: string; name: string; url: string}",
                    "resolved": "{ id: string; name: string; url: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "items",
                "methodName": "watchItems"
            }];
    }
}
//# sourceMappingURL=index.js.map
