import { Host, h } from "@stencil/core";
/**
 * Notification bar component.
 * @slot - The text of the notification.
 * @cssprop --z-notification--top-offset - The top offset of the notification. Use it when `sticky` prop is set to `true` and you need the notification to stay under other sticky elements. Default: 0px.
 */
export class ZNotification {
    handleActionButtonClick(e) {
        e.preventDefault();
        this.notificationAction.emit();
    }
    handleCloseButtonClick(e) {
        e.preventDefault();
        this.notificationClose.emit();
    }
    constructor() {
        this.contenticonname = undefined;
        this.actiontext = undefined;
        this.type = undefined;
        this.showclose = false;
        this.showshadow = false;
        this.sticky = false;
        this.handleActionButtonClick = this.handleActionButtonClick.bind(this);
        this.handleCloseButtonClick = this.handleCloseButtonClick.bind(this);
    }
    render() {
        var _a;
        return (h(Host, { key: '3681c9216f7ab0ce532c8b1ed013d7af611151de' }, this.contenticonname && (h("z-icon", { key: 'e7c538a5583873ed4ad95885f1199050b89f6732', class: "status-icon", name: this.contenticonname, width: 16, height: 16 })), h("div", { key: '93855c8906e6a65fa2d762fc447d14ee7a456b53', class: "content-container" }, h("div", { key: '526f760b7739c28154195e7a01ce66b185ccb068', class: "content-text" }, h("slot", { key: '56313ec91ad750e57af3035455aa89db3880ae4e' })), !!((_a = this.actiontext) === null || _a === void 0 ? void 0 : _a.trim()) && (h("button", { key: 'fc2de2fa3ff7cdf5e522f009efa41af06f8a6cca', class: "action-button", type: "button", onClick: this.handleActionButtonClick }, this.actiontext))), this.showclose && (h("button", { key: '3ba0d198a3617d1a05fb33eb8f3ceb9b0d685503', class: "close-button", type: "button", onClick: this.handleCloseButtonClick }, h("z-icon", { key: '0bba4473674bee1c8c4abbc5792c9cab84c06088', name: "multiply-circle", width: 16, height: 16 })))));
    }
    static get is() { return "z-notification"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["styles.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["styles.css"]
        };
    }
    static get properties() {
        return {
            "contenticonname": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Name of the icon on the left of the content"
                },
                "attribute": "contenticonname",
                "reflect": false
            },
            "actiontext": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Action button text"
                },
                "attribute": "actiontext",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NotificationType",
                    "resolved": "NotificationType.ERROR | NotificationType.SUCCESS | NotificationType.WARNING",
                    "references": {
                        "NotificationType": {
                            "location": "import",
                            "path": "../../beans",
                            "id": "src/beans/index.tsx::NotificationType"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Alert variant type"
                },
                "attribute": "type",
                "reflect": true
            },
            "showclose": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Enable close icon"
                },
                "attribute": "showclose",
                "reflect": false,
                "defaultValue": "false"
            },
            "showshadow": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "deprecated",
                            "text": "shadow is available only for the `sticky` version of the notification."
                        }],
                    "text": "Enable shadow."
                },
                "attribute": "showshadow",
                "reflect": true,
                "defaultValue": "false"
            },
            "sticky": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Enable sticky notification bar."
                },
                "attribute": "sticky",
                "reflect": true,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "notificationAction",
                "name": "notificationAction",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Call to action clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "notificationClose",
                "name": "notificationClose",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Close button clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=index.js.map
