import { html } from "lit";
import { styleMap } from "lit/directives/style-map.js";
import { getColorTokenArgConfig } from "../../utils/storybook-utils";
import "./index";
const StoryMeta = {
    title: "ZPagination",
    component: "z-pagination",
    argTypes: {
        "totalPages": {
            control: {
                type: "number",
                min: 1,
            },
        },
        "visiblePages": {
            control: {
                type: "number",
                min: 1,
            },
            if: {
                arg: "split",
                truthy: false,
            },
        },
        "currentPage": {
            control: {
                type: "number",
                min: 1,
            },
        },
        "skip": {
            control: {
                type: "number",
                min: 1,
            },
        },
        "edges": {
            if: {
                arg: "split",
                truthy: false,
            },
        },
        "split": {
            control: {
                type: "number",
                min: 1,
            },
        },
        "--z-pagination-background-color": getColorTokenArgConfig(),
        "--z-pagination-background-color-hover": getColorTokenArgConfig(),
    },
    args: {
        "label": "",
        "navArrows": true,
        "totalPages": 201,
        "visiblePages": 5,
        "currentPage": 1,
        "goToPage": false,
        "split": undefined,
        "skip": 0,
        "edges": false,
        "--z-pagination-background-color": "var(--color-background)",
        "--z-pagination-background-color-hover": "var(--color-surface01)",
    },
    render: (args) => html `
    <z-pagination
      .label=${args.label}
      .navArrows=${args.navArrows}
      .totalPages=${args.totalPages}
      .visiblePages=${args.visiblePages}
      .skip=${args.skip}
      .currentPage=${args.currentPage}
      .goToPage=${args.goToPage}
      .edges=${args.edges}
      style=${styleMap({
        "--z-pagination-background-color": args["--z-pagination-background-color"],
        "--z-pagination-background-color-hover": args["--z-pagination-background-color-hover"],
    })}
    ></z-pagination>
  `,
};
export default StoryMeta;
export const VisiblePages = {
    parameters: {
        controls: {
            exclude: ["split"],
        },
    },
};
/**
 * > Note that enabling `split` will shut off `visiblePages` and `edges`.
 */
export const Split = {
    args: {
        split: 1,
    },
    parameters: {
        controls: {
            exclude: ["edges", "visiblePages"],
        },
    },
};
export const Edges = {
    args: {
        edges: true,
    },
    parameters: {
        controls: {
            exclude: ["split"],
        },
    },
};
export const Skip = {
    args: {
        skip: 10,
    },
};
//# sourceMappingURL=index.stories.js.map
