import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { O as OffCanvasVariant, u as TransitionDirection } from './index2.js';

const stylesCss = ".sc-z-offcanvas-h{font-family:var(--font-family-sans);font-weight:var(--font-rg)}[variant=\"pushcontent\"].sc-z-offcanvas-h:not([transitiondirection=\"up\"]){overflow:hidden}.canvas-container.sc-z-offcanvas{display:flex;overflow:hidden;min-width:100%;height:100%;background:var(--color-surface01);transition:transform 0.4s ease-out}.sc-z-offcanvas-h>*.sc-z-offcanvas{position:fixed;top:var(--z-offcanvas--top-space, 0);right:0;bottom:0;left:0}[open].sc-z-offcanvas-h>*.sc-z-offcanvas{height:calc(100% - var(--z-offcanvas--top-space, 0px))}[transitiondirection=\"right\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{transform:translateX(-100%)}[transitiondirection=\"left\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{transform:translateX(100%)}[open][transitiondirection=\"right\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas,[open][transitiondirection=\"left\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{transform:translateX(0)}[transitiondirection=\"up\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{top:auto;bottom:0;height:var(--z-offcanvas--container-height, 90%);transform:translateY(100%)}[transitiondirection=\"up\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas,[variant=\"overlay\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{z-index:1001}[open][transitiondirection=\"up\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{transform:translateY(0)}[variant=\"pushcontent\"].sc-z-offcanvas-h:not([transitiondirection=\"up\"])>.canvas-container.sc-z-offcanvas{position:relative;height:100%}[variant=\"pushcontent\"].sc-z-offcanvas-h:not([open]){display:none}[skip-animation].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{transition:none}.canvas-background.sc-z-offcanvas{z-index:1000;width:100%;height:100%;background-color:var(--gray900);opacity:0;pointer-events:none;transition:opacity 0.4s ease-out}[open].sc-z-offcanvas-h>.canvas-background.sc-z-offcanvas{opacity:0.7;pointer-events:unset}.canvas-container.sc-z-offcanvas>.canvas-content.sc-z-offcanvas{overflow:hidden auto;flex:1 auto;padding:0 calc(var(--space-unit) * 2);margin:calc(var(--space-unit) * 2) calc(var(--space-unit) / 2) calc(var(--space-unit) * 2) 0}@media (min-width: 768px){[variant=\"pushcontent\"].sc-z-offcanvas-h:not([transitiondirection=\"up\"]){flex:none}.canvas-container.sc-z-offcanvas{width:max(var(--z-offcanvas--container-width, 375px), 375px);min-width:375px}[transitiondirection=\"up\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{width:100%}[transitiondirection=\"right\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{right:auto;left:0}[transitiondirection=\"left\"].sc-z-offcanvas-h>.canvas-container.sc-z-offcanvas{right:0;left:auto}}";
const ZOffcanvasStyle0 = stylesCss;

const ZOffcanvas = /*@__PURE__*/ proxyCustomElement(class ZOffcanvas extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.canvasOpenStatusChanged = createEvent(this, "canvasOpenStatusChanged", 7);
        this.variant = OffCanvasVariant.PUSHCONTENT;
        this.open = false;
        this.transitiondirection = TransitionDirection.LEFT;
        this.skipLoadAnimation = false;
        this.skipAnimation = false;
    }
    /**
     * Stop the event default behavior and propagation when the offcanvas is closed.
     */
    stopEvent(event) {
        if (this.open) {
            return;
        }
        event.preventDefault();
        event.stopPropagation();
    }
    /**
     * Hide the body overflow when the offcanvas is open.
     */
    handlePageOverflow() {
        const overflow = this.variant === OffCanvasVariant.OVERLAY || this.transitiondirection === TransitionDirection.UP
            ? "overflow-y"
            : "overflow-x";
        document.body.style[overflow] = this.open ? "hidden" : "";
    }
    onOpenChanged() {
        var _a;
        this.canvasOpenStatusChanged.emit(this.open);
        if (!this.open) {
            // when the offcanvas is closing, wait for the transitionend event to end before handling the body overflow
            const listenerCallback = () => {
                this.handlePageOverflow();
                this.canvasContainer.removeEventListener("transitionend", listenerCallback);
            };
            (_a = this.canvasContainer) === null || _a === void 0 ? void 0 : _a.addEventListener("transitionend", listenerCallback);
        }
        else {
            this.handlePageOverflow();
        }
    }
    componentWillLoad() {
        if (this.open) {
            this.skipAnimation = true;
        }
    }
    componentDidLoad() {
        this.handlePageOverflow();
    }
    componentDidRender() {
        this.skipAnimation = false;
    }
    connectedCallback() {
        this.handlePageOverflow();
    }
    disconnectedCallback() {
        this.open = false;
    }
    render() {
        return (h(Host, { key: '299c69d8788f7cf2e12b6f6eb151c3b7c5e4e271', "skip-animation": this.skipAnimation, "aria-hidden": !this.open ? "true" : null }, h("div", { key: '2620f2f0ef0741cbe6e5d63f7ed38299fb253852', class: "canvas-container", role: "presentation", ref: (el) => (this.canvasContainer = el) }, h("div", { key: '1df851d5c4d1fddb24a62c5e3d92a7181bd36d05', class: "canvas-content z-scrollbar", role: "presentation" }, h("slot", { key: '89303666352d55c9a92a0b4cecc9bea8d42125f7', name: "canvasContent" }))), (this.variant == OffCanvasVariant.OVERLAY || this.transitiondirection === TransitionDirection.UP) && (h("div", { key: '197e3eb34f5981c52a553875157a3a02993f7684', class: "canvas-background", onClick: () => (this.open = false) }))));
    }
    static get watchers() { return {
        "variant": ["handlePageOverflow"],
        "open": ["onOpenChanged"]
    }; }
    static get style() { return ZOffcanvasStyle0; }
}, [6, "z-offcanvas", {
        "variant": [513],
        "open": [1540],
        "transitiondirection": [513],
        "skipLoadAnimation": [4, "skip-load-animation"],
        "skipAnimation": [32]
    }, [[2, "click", "stopEvent"], [2, "focusin", "stopEvent"]], {
        "variant": ["handlePageOverflow"],
        "open": ["onOpenChanged"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["z-offcanvas"];
    components.forEach(tagName => { switch (tagName) {
        case "z-offcanvas":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ZOffcanvas);
            }
            break;
    } });
}

export { ZOffcanvas as Z, defineCustomElement as d };

//# sourceMappingURL=index22.js.map