import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { N as NavigationTabsOrientation, a as NavigationTabsSize, b as NavigationTabsKeyboardEvents } from './index2.js';
import { d as defineCustomElement$2 } from './index9.js';

const stylesCss = "z-navigation-tabs{position:relative;z-index:0;display:flex;overflow:hidden;flex-direction:row;font-family:var(--font-family-sans);font-weight:var(--font-rg)}z-navigation-tabs,z-navigation-tabs *{box-sizing:border-box}z-navigation-tabs>nav::-webkit-scrollbar{display:none}z-navigation-tabs .navigation-button{position:absolute;z-index:1;display:flex;align-items:center;justify-content:center;padding:0;border:none;margin:0;background-color:var(--z-navigation-tabs-nav-buttons-bg, var(--color-surface01));border-radius:var(--border-no-radius);box-shadow:0 0 4px 1px var(--shadow-color-base);cursor:pointer;fill:var(--z-navigation-tabs-nav-buttons-fg, var(--color-primary01));outline:none}z-navigation-tabs .navigation-button:disabled{display:none}z-navigation-tabs>nav{z-index:0;display:flex;overflow:auto;align-items:center;justify-content:flex-start;scroll-behavior:smooth;scrollbar-width:none}z-navigation-tabs[orientation=\"horizontal\"]>nav{width:100%}z-navigation-tabs[orientation=\"horizontal\"] .navigation-button{top:0;width:calc(var(--space-unit) * 4);height:100%}z-navigation-tabs[orientation=\"horizontal\"] .navigation-button:first-child{left:0}z-navigation-tabs[orientation=\"horizontal\"] .navigation-button:last-child{right:0}z-navigation-tabs[orientation=\"vertical\"]{width:fit-content;flex-direction:column}z-navigation-tabs[orientation=\"vertical\"]>nav{height:100%;flex-direction:column;align-items:stretch}z-navigation-tabs[orientation=\"vertical\"] .navigation-button{left:0;width:100%;height:calc(var(--space-unit) * 4)}z-navigation-tabs[orientation=\"vertical\"] .navigation-button:first-child{top:0}z-navigation-tabs[orientation=\"vertical\"] .navigation-button:last-child{bottom:0}z-navigation-tabs[size=\"small\"][orientation=\"vertical\"] .navigation-button{height:calc(var(--space-unit) * 4)}z-navigation-tabs>nav>*{position:relative;z-index:0;display:inline-flex;width:auto;align-items:center;justify-content:center;padding:calc(var(--space-unit) * 2) calc(var(--space-unit) * 5);border:none;margin:0;background-color:unset;border-radius:var(--border-no-radius);color:var(--color-primary01);cursor:pointer;fill:currentcolor;font-family:var(--font-family-sans);font-size:inherit;gap:var(--space-unit);letter-spacing:inherit;line-height:inherit;outline:none;text-align:center;white-space:nowrap}z-navigation-tabs>nav>a{text-decoration:none}z-navigation-tabs>nav>*:focus:focus-visible{z-index:1;box-shadow:inset 0 0 2px 2px var(--blue800)}z-navigation-tabs>nav>:not([disabled]):hover{background-color:var(--color-background)}z-navigation-tabs>nav>button[disabled]{color:var(--color-disabled03);cursor:not-allowed;fill:currentcolor;pointer-events:all}z-navigation-tabs>nav>:not([disabled]):hover,nav>[aria-selected=\"true\"]{color:var(--color-hover-primary);fill:currentcolor}z-navigation-tabs>nav>:not([disabled]):hover::after,nav>[aria-selected=\"true\"]::after{position:absolute;background-color:var(--color-hover-primary);content:\"\"}z-navigation-tabs[orientation=\"horizontal\"]>nav>:not([disabled]):hover::after,z-navigation-tabs[orientation=\"horizontal\"]>nav>[aria-selected=\"true\"]::after{bottom:0;left:0;width:100%;height:var(--border-size-large)}z-navigation-tabs>nav>* z-icon{--z-icon-width:calc(var(--space-unit) * 2);--z-icon-height:calc(var(--space-unit) * 2);display:flex;margin:0}z-navigation-tabs[size=\"small\"][orientation=\"horizontal\"]>nav>*{padding:var(--space-unit) calc(var(--space-unit) * 2)}z-navigation-tabs[size=\"small\"][orientation=\"horizontal\"]>nav>:not([disabled]):hover::after,z-navigation-tabs[size=\"small\"][orientation=\"horizontal\"]>nav>[aria-selected=\"true\"]::after{height:var(--border-size-medium)}z-navigation-tabs[size=\"small\"]:not([orientation=\"vertical\"])>nav>* z-icon{--z-icon-width:14px;--z-icon-height:14px}z-navigation-tabs[orientation=\"vertical\"]>nav>*{padding:calc(var(--space-unit) * 3) calc(var(--space-unit) * 2)}z-navigation-tabs[orientation=\"vertical\"]>nav>*>:not(z-icon){display:none}z-navigation-tabs[orientation=\"vertical\"]>nav>:not([disabled]):hover::after,z-navigation-tabs[orientation=\"vertical\"]>nav>[aria-selected=\"true\"]::after{top:0;right:0;width:var(--border-size-large);height:100%}";
const ZNavigationTabsStyle0 = stylesCss;

const ZNavigationTabs$1 = /*@__PURE__*/ proxyCustomElement(class ZNavigationTabs extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.selected = createEvent(this, "selected", 7);
        /**
         * Index of the last tab that held focus.
         */
        this.focusedTab = undefined;
        this.ariaLabel = "";
        this.orientation = NavigationTabsOrientation.HORIZONTAL;
        this.size = NavigationTabsSize.BIG;
        this.selectedTab = undefined;
        this.canNavigate = undefined;
        this.canNavigatePrev = undefined;
        this.canNavigateNext = undefined;
    }
    /**
     * Getter for the direction to check based on current orientation.
     */
    get direction() {
        return this.orientation == NavigationTabsOrientation.HORIZONTAL ? "Left" : "Top";
    }
    /**
     * Getter for the dimension to check based on current orientation.
     */
    get dimension() {
        return this.orientation == NavigationTabsOrientation.HORIZONTAL ? "Width" : "Height";
    }
    get tabs() {
        return Array.from(this.nav.children);
    }
    /**
     * Scroll into view to center the tab.
     */
    scrollToTab(tabElement) {
        const container = tabElement.parentElement;
        if (!container) {
            return;
        }
        setTimeout(() => {
            const isHorizontal = this.orientation === NavigationTabsOrientation.HORIZONTAL;
            const containerRect = container.getBoundingClientRect();
            const tabRect = tabElement.getBoundingClientRect();
            const offset = isHorizontal ? tabRect.left - containerRect.left : tabRect.top - containerRect.top;
            const containerSize = isHorizontal ? container.clientWidth : container.clientHeight;
            const tabSize = isHorizontal ? tabElement.clientWidth : tabElement.clientHeight;
            const scrollAmount = offset - containerSize / 2 + tabSize / 2;
            container.scrollTo({
                [isHorizontal ? "left" : "top"]: container[isHorizontal ? "scrollLeft" : "scrollTop"] + scrollAmount,
                behavior: "smooth",
            });
        }, 100);
    }
    /**
     * Scroll the navigation bar half of its size backward.
     */
    navigateBackwards() {
        this.nav.scrollBy({
            [this.direction.toLowerCase()]: 0 - this.nav[`client${this.dimension}`] / 2,
            behavior: "smooth",
        });
    }
    /**
     * Scroll the navigation bar half of its size forward.
     */
    navigateForward() {
        this.nav.scrollBy({
            [this.direction.toLowerCase()]: this.nav[`scroll${this.direction}`] + this.nav[`client${this.dimension}`] / 2,
            behavior: "smooth",
        });
    }
    /**
     * Check if a keyboard event was triggered by an arrow key.
     */
    isArrowNavigation(e) {
        return Object.values(NavigationTabsKeyboardEvents).includes(e.key);
    }
    /**
     * Check if the navigation buttons are needed.
     */
    checkScrollVisible() {
        if (!this.nav) {
            return;
        }
        this.canNavigate = this.nav[`scroll${this.dimension}`] > this.nav[`client${this.dimension}`];
    }
    /**
     * Check if navigation buttons can be enabled for each direction.
     */
    checkScrollEnabled() {
        if (!this.nav) {
            return;
        }
        this.canNavigateNext =
            this.nav[`scroll${this.direction}`] + this.nav[`client${this.dimension}`] < this.nav[`scroll${this.dimension}`];
        this.canNavigatePrev = this.nav[`scroll${this.direction}`] > 0;
    }
    /**
     * When the selected tab changes, update the `aria-selected` attribute on each tab and scroll to the selected tab.
     */
    onTabSelected() {
        this.tabs.forEach((tab, i) => {
            const zicon = tab.querySelector("z-icon");
            const strokeIcon = zicon === null || zicon === void 0 ? void 0 : zicon.name.replace("-filled", "");
            if (i !== this.selectedTab) {
                tab.setAttribute("aria-selected", "false");
                tab.tabIndex = -1;
                if (zicon) {
                    zicon.name = strokeIcon;
                }
                return;
            }
            if (zicon) {
                zicon.name = `${strokeIcon}-filled`;
            }
            tab.setAttribute("aria-selected", "true");
        });
        this.selected.emit(this.selectedTab);
        if (this.selectedTab !== undefined) {
            this.scrollToTab(this.tabs[this.selectedTab]);
        }
    }
    /**
     * Handle click on the tabs.
     * @param event `click` event triggered by a child tab
     */
    handleTabClick(event) {
        const clickedTab = event.target.closest("[role='tab']");
        if (!this.tabs.some((child) => child.contains(clickedTab))) {
            return;
        }
        this.selectedTab = this.tabs.indexOf(clickedTab);
    }
    /**
     * When a tab is focused, temporarily set to -1 the `tabindex` of the selected tab (if any) and set the `focusedTab` to the index of the focused tab.
     */
    onTabFocusIn(event) {
        const focused = this.tabs.findIndex((tab) => tab.contains(event.target));
        if (focused === -1) {
            return;
        }
        if (this.selectedTab !== undefined) {
            this.tabs[this.selectedTab].tabIndex = -1;
        }
        this.focusedTab = focused;
        this.tabs[this.focusedTab].tabIndex = -1;
        this.scrollToTab(this.tabs[this.focusedTab]);
    }
    /**
     * Handle keyboard navigation through tabs with arrow keys.
     */
    navigateThroughTabs(event) {
        if (!this.tabs.some((tab) => tab.contains(event.target)) || !this.isArrowNavigation(event)) {
            return true;
        }
        event.preventDefault();
        if ((event.key === NavigationTabsKeyboardEvents.RIGHT && this.orientation == NavigationTabsOrientation.HORIZONTAL) ||
            (event.key === NavigationTabsKeyboardEvents.DOWN && this.orientation == NavigationTabsOrientation.VERTICAL)) {
            // Move forward
            this.focusedTab++;
            if (this.focusedTab >= this.tabs.length) {
                this.focusedTab = 0;
            }
        }
        else if ((event.key === NavigationTabsKeyboardEvents.LEFT && this.orientation == NavigationTabsOrientation.HORIZONTAL) ||
            (event.key === NavigationTabsKeyboardEvents.UP && this.orientation == NavigationTabsOrientation.VERTICAL)) {
            // Move backward
            this.focusedTab--;
            if (this.focusedTab < 0) {
                this.focusedTab = this.tabs.length - 1;
            }
        }
        // Ignore disabled tabs
        if (this.tabs[this.focusedTab].hasAttribute("disabled") &&
            this.tabs[this.focusedTab].getAttribute("disabled") !== "false") {
            return this.navigateThroughTabs(event);
        }
        this.tabs[this.focusedTab].focus();
        this.scrollToTab(this.tabs[this.focusedTab]);
    }
    /**
     * If the focus is not going on a tab (`relatedTarget` is the new focused element), set to 0 the `tabindex` of the selected tab or the one of the first tab, then unset the `focusedTab`.
     */
    onTabFocusOut(event) {
        var _a;
        if (!this.tabs.some((tab) => tab.contains(event.relatedTarget))) {
            this.tabs[(_a = this.selectedTab) !== null && _a !== void 0 ? _a : 0].tabIndex = 0;
            this.focusedTab = undefined;
        }
    }
    connectedCallback() {
        this.resizeObserver = new ResizeObserver(() => this.checkScrollVisible());
    }
    componentDidLoad() {
        var _a;
        // Set role and tabindex to each slotted tab
        this.tabs.forEach((tab) => {
            tab.setAttribute("role", "tab");
            tab.tabIndex = -1;
        });
        const preselectedTab = (_a = this.selectedTab) !== null && _a !== void 0 ? _a : this.tabs.findIndex((tab) => tab.ariaSelected === "true");
        if (preselectedTab !== -1) {
            this.selectedTab = preselectedTab;
            this.tabs[preselectedTab].tabIndex = 0;
            this.onTabSelected();
        }
        else {
            this.tabs[0].tabIndex = 0;
        }
        this.resizeObserver.observe(this.nav);
    }
    disconnectedCallback() {
        var _a;
        (_a = this.resizeObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    render() {
        return (h(Host, { key: 'b7bdbf2b202dead64ed98f5865e9d46e71898bf9', class: {
                "interactive-2": this.size === NavigationTabsSize.SMALL,
                "interactive-1": this.size !== NavigationTabsSize.SMALL,
            }, scrollable: this.canNavigate }, h("button", { key: 'aa1df34b54cf4b8848aed44cd3927ee17777a34b', class: "navigation-button", onClick: this.navigateBackwards.bind(this), tabIndex: -1, disabled: !this.canNavigatePrev, "aria-label": "Mostra elementi precedenti", hidden: !this.canNavigate }, h("z-icon", { key: '2bad56e221bc2691d8ca6cea0a013c6d92d7f8c1', name: this.orientation === NavigationTabsOrientation.HORIZONTAL ? "chevron-left" : "chevron-up", width: 16, height: 16 })), h("nav", { key: '8dd45e59019ac799f1fffdf7245d0c902455c0a6', role: "tablist", "aria-label": this.ariaLabel, ref: (el) => (this.nav = el !== null && el !== void 0 ? el : this.nav), onScroll: this.checkScrollEnabled.bind(this), "aria-orientation": this.orientation }, h("slot", { key: '3d243470caae97c068a2ae23b05078695c2ae367' })), h("button", { key: '080cf9e973e320a795c95acfb3bd41b4ee9eacd9', class: "navigation-button", onClick: this.navigateForward.bind(this), tabIndex: -1, disabled: !this.canNavigateNext, "aria-label": "Mostra elementi successivi", hidden: !this.canNavigate }, h("z-icon", { key: '293fc3b81bee46d928c8461be0225be73efcc9bb', name: this.orientation === NavigationTabsOrientation.HORIZONTAL ? "chevron-right" : "chevron-down", width: 16, height: 16 }))));
    }
    get host() { return this; }
    static get watchers() { return {
        "canNavigate": ["checkScrollEnabled"],
        "selectedTab": ["onTabSelected"]
    }; }
    static get style() { return ZNavigationTabsStyle0; }
}, [4, "z-navigation-tabs", {
        "ariaLabel": [1, "aria-label"],
        "orientation": [513],
        "size": [513],
        "selectedTab": [1026, "selected-tab"],
        "canNavigate": [32],
        "canNavigatePrev": [32],
        "canNavigateNext": [32]
    }, [[0, "click", "handleTabClick"], [0, "focusin", "onTabFocusIn"], [0, "keydown", "navigateThroughTabs"], [0, "focusout", "onTabFocusOut"]], {
        "canNavigate": ["checkScrollEnabled"],
        "selectedTab": ["onTabSelected"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["z-navigation-tabs", "z-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "z-navigation-tabs":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ZNavigationTabs$1);
            }
            break;
        case "z-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const ZNavigationTabs = ZNavigationTabs$1;
const defineCustomElement = defineCustomElement$1;

export { ZNavigationTabs, defineCustomElement };

//# sourceMappingURL=z-navigation-tabs.js.map