import { g as KeyboardCode, p as Device } from './index-fe87283d.js';
import { B as Breakpoints } from './breakpoints-d148bfde.js';

/**
 * Return boolean value for passed value if a boolean corresponding value is found
 * Return passed value otherwise
 */
function boolean(value) {
    switch (value) {
        case true:
        case "true":
        case 1:
        case "1":
        case "on":
        case "yes":
            return true;
        case false:
        case "false":
        case 0:
        case "0":
        case "off":
        case "no":
            return false;
        default:
            return value;
    }
}
function randomId() {
    return Math.random().toString(36).replace("0.", "");
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function handleKeyboardSubmit(ev, callback, ...args) {
    if (ev.code === KeyboardCode.ENTER || ev.code === KeyboardCode.SPACE) {
        ev.preventDefault();
        callback(...args);
    }
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function handleEnterKeydSubmit(ev, callback, ...args) {
    if (ev.code === KeyboardCode.ENTER) {
        ev.preventDefault();
        callback(...args);
    }
}
function getClickedElement(elem = null) {
    if (!elem) {
        elem = document.activeElement;
    }
    if (elem && elem.shadowRoot && elem.shadowRoot.activeElement) {
        elem = elem.shadowRoot.activeElement;
        return getClickedElement(elem);
    }
    return elem;
}
function getElementTree(elem, tree = []) {
    tree.push(elem);
    if (elem.parentElement) {
        elem = elem.parentElement;
        return getElementTree(elem, tree);
    }
    else if (elem.parentNode && elem.parentNode.host) {
        elem = elem.parentNode.host;
        return getElementTree(elem, tree);
    }
    return tree;
}
/**
 * Get the current device type based on the window width.
 * @returns {Device} - The current device type
 */
function getDevice() {
    switch (true) {
        case window.innerWidth <= Breakpoints.MOBILE:
            return Device.MOBILE;
        case window.innerWidth <= Breakpoints.TABLET:
            return Device.TABLET;
        case window.innerWidth <= Breakpoints.DESKTOP:
            return Device.DESKTOP;
        default:
            return Device.DESKTOP_WIDE;
    }
}
function convertJson(data) {
    try {
        return JSON.parse(data);
    }
    catch (_a) {
        return false;
    }
}
function colorFromId(id) {
    const prefix = "avatar-C"; // prefix for color vars name
    const colorsCount = 19; // available colors
    const seed = Math.ceil(2 ** 31 - 1) * parseFloat(`0.${id}`);
    let color = Math.ceil(colorsCount * (seed % 1));
    // if result of mc is 0
    // es.: 3895229
    if (color === 0) {
        color = 1;
    }
    return `${prefix}${color.toString().padStart(2, "0")}`;
}
/**
 * Check if an element contains another element, checking both light and shadow DOM.
 * @param ancestor Ancestor element
 * @param descendant Descendant element
 */
function containsElement(ancestor, descendant) {
    var _a;
    return ancestor.contains(descendant) || !!((_a = ancestor.shadowRoot) === null || _a === void 0 ? void 0 : _a.contains(descendant));
}

export { containsElement as a, boolean as b, colorFromId as c, handleKeyboardSubmit as d, getElementTree as e, getClickedElement as f, getDevice as g, handleEnterKeydSubmit as h, convertJson as i, randomId as r };

//# sourceMappingURL=utils-c7062cf7.js.map