import { EventEmitter } from "../../../stencil-public-runtime";
import { BookCardVariant } from "../../../beans";
/**
 * @slot cta - top right cta (e.g. bookmark icon)
 * @slot ebook - as default, it shows laZ ebook link
 * @slot tags - tags section, default empty
 * @slot data - external link and pill, default empty
 * @slot apps - list of card-related apps, default empty
 * @slot coverOverlay - purple layer on top of book cover
 * @cssprop --z-book-card-portrait-cover-height - set custom cover height for portrait variant - default 378px
 * @cssprop --z-book-card-title-lines - set title avilable lines - default 2
 * @cssprop --z-book-card-title-word-break - set title word-break rule - default initial
 * @cssprop --z-book-card-subtitle-lines - set subtitle available lines - default 1
 * @cssprop --z-book-card-subtitle-word-break - set subtitle word-break rule - default break-all
 * @cssprop --z-book-card-authors-lines - set authors available lines - default 1
 * @cssprop --z-book-card-authors-word-break - set authors word-break rule - default break-all
 */
export declare class ZBookCard {
    hostElement: HTMLZBookCardElement;
    /** Card variant: landscape, portrait */
    variant: BookCardVariant;
    /** Cover URL */
    cover: string;
    /** Opera title (card title) */
    operaTitle: string;
    /** [optional] Volume title (card subvolume) */
    volumeTitle?: string;
    /** [optional] Authors */
    authors?: string;
    /** [optional] Main ISBN */
    isbn?: string;
    /** [optional] ISBN label */
    isbnLabel: string;
    /** [optional] year */
    year?: string;
    /** [optional] Show link to the ebook resource */
    ebookUrl?: string;
    /** [optional] Fallback cover URL */
    fallbackCover?: string;
    /** [optional] Set a specific h level as html tag for opera title */
    titleHtmlTag?: string;
    /** click on ebook link */
    ebookClick: EventEmitter;
    private emitEbookClick;
    private renderCover;
    private renderYear;
    private renderAuthors;
    private renderOperaTitle;
    private renderVolumeTitle;
    private renderIsbn;
    private renderEbook;
    private renderCtaSlot;
    render(): HTMLZBookCardElement;
}
