import { EventEmitter } from "../../../stencil-public-runtime";
import { ButtonVariant, ZFileUploadType } from "../../../beans";
export type ZFileUploadError = {
    cause: "format" | "size";
    message: string;
};
export declare class ZFileUpload {
    /** Prop indicating the file upload type - can be default or dragdrop */
    type: ZFileUploadType;
    /** Prop indicating the button variant*/
    buttonVariant?: ButtonVariant;
    /** Prop indicating the accepted file type: ex ".pdf, .doc, .jpg" */
    acceptedFormat?: string;
    /** Max file dimension in Megabyte */
    fileMaxSize?: number;
    /** Title */
    mainTitle?: string;
    /** Description */
    description?: string;
    /** upoload button label */
    uploadBtnLabel?: string;
    /** drag & drop button label */
    dragAndDropLabel?: string;
    /** allowed file message */
    allowedFilesMessage?: string;
    /** upload clickable message */
    uploadClickableMessage?: string;
    /** upload message */
    uploadMessage?: string;
    /** error modal title */
    errorModalTitle?: string;
    /** error modal message */
    errorModalMessage?: string;
    /** loaded files label */
    uploadedFilesLabel?: string;
    /** uploaded files history rendering */
    hasFileSection?: boolean;
    /** Value to set on the file input's `name` attribute (for use with forms) */
    inputName?: string;
    /**
     * Whether to show errors in the internal modal or leave the handling to the app.
     * Errors will still be emitted.
     */
    showErrors: boolean;
    /** Internal store of the component type. It will change when viewport goes from desktop to tablet/mobile and vice versa */
    private _type;
    /** Files added by the user */
    files: File[];
    /** Map of files whose upload caused an error and the relative errors, with the cause and a message */
    invalidFiles: Map<string, ZFileUploadError[]>;
    /** Input ref */
    private input;
    /** Emitted when user select one or more files */
    fileInput: EventEmitter<File>;
    /**
     * Emits an array of error messages related to one or more files not allowed.
     * Emitted when some file is dropped or selected.
     */
    fileError: EventEmitter<{
        file: string;
        errors: ZFileUploadError[];
    }>;
    host: HTMLZFileUploadElement;
    private errorModal;
    /** Listen `removeFile` event sent from z-file component */
    onFileRemoved(e: CustomEvent): void;
    /** Listen fileDropped event sent from z-dragdrop-area component */
    fileDroppedListener(e: CustomEvent): void;
    /** Get the list of uploaded files */
    getFiles(): Promise<File[]>;
    /** Remove a previously uploaded file */
    removeFile(fileName: string): Promise<void>;
    private checkFilesValidity;
    private resetErrors;
    private onFilesChange;
    componentWillLoad(): void;
    componentDidUpdate(): void;
    private renderDescription;
    private renderAllowedFilesMessage;
    private renderFileSection;
    private renderInput;
    private renderUploadButton;
    private renderUploadLink;
    private renderDefaultMode;
    private renderDragDropMode;
    private renderFileErrors;
    render(): HTMLZFileUploadElement;
}
