import { EventEmitter } from "../../stencil-public-runtime";
/**
 * @slot title - Slot for the main title
 * @slot top-subtitle - Slot for the top subtitle. It will not appear in stuck header.
 * @slot stucked-title - Title for the stuck header. By default it uses the text from the `title` slot.
 * @slot product-logo - To insert the product logo, it should be used with an img tag.
 * @cssprop --app-header-content-max-width - Use it to set header's content max width. Useful when the project use a fixed width layout. Defaults to `100%`.
 * @cssprop --app-header-top-offset - Top offset for the stuck header. Useful when there are other fixed elements above the header. Defaults to `48px` (the height of the main topbar).
 * @cssprop --app-header-bg - Header background color. Defaults to `--color-surface01`.
 * @cssprop --app-header-text-color - Header text color. Defaults to `--color-default-text`.
 * @cssprop --app-header-stucked-bg - Stuck header background color. Defaults to `--color-surface01`.
 * @cssprop --app-header-stucked-text-color - Stuck header text color. Defaults to `--color-default-text`.
 */
export declare class ZAppHeader {
    hostElement: HTMLZAppHeaderElement;
    /**
     * Stuck mode for the header.
     * You can programmatically set it using an IntersectionObserver.
     */
    stuck: boolean;
    /**
     * When enabled, the menu bar is not displayed and a burger icon appears to open the offcanvas menu. Automatically enabled on mobile and when the menu items overflow the container.
     */
    enableOffcanvas: boolean;
    /**
     * Enable the search bar.
     */
    enableSearch: boolean;
    /**
     * Placeholder text for the search bar.
     */
    searchPlaceholder: string;
    /**
     * Search string for the search bar.
     */
    searchString: string;
    /**
     * Url to the search page.
     * Set this prop and `enableSearch` to show a link-button on mobile and tablet viewports, instead of the normal searchbar.
     * The link will also appear on the sticky header.
     */
    searchPageUrl: string;
    /**
     * Enable laZ logo.
     */
    enableZLogo: boolean;
    /**
     * The opening state of the drawer.
     */
    drawerOpen: boolean;
    /**
     * Emitted when the `stuck` state of the header changes
     */
    sticking: EventEmitter;
    /**
     * The stuck state of the bar.
     */
    private _stuck;
    /**
     * Current count of menu items.
     */
    private menuLength;
    private isMobile;
    private isTablet;
    private container?;
    private menuElements;
    private menuWidth;
    private closeDrawerButton;
    private burgerButton;
    private menuResizeObserver;
    private stuckIntersecObserver?;
    onStuck(): void;
    setMenuFloatingMode(): void;
    onStuckChange(): void;
    private get title();
    private get scrollParent();
    private get canShowMenu();
    private get focusableMenu();
    private openDrawer;
    private closeDrawer;
    private collectMenuElements;
    /** Automatically use offcanvas mode when the menubar doesn't fit in the header. */
    private setupMenuResizeObserver;
    private hasSlot;
    private moveFocus;
    private onOffcanvasKeydown;
    /** Close each menu except the one receiving focus/click, if any */
    manageMenus(ev: FocusEvent | PointerEvent): void;
    handleKeydown(ev: KeyboardEvent): void;
    private renderSeachbar;
    private renderProductLogos;
    private renderMenuButton;
    private renderOffcanvas;
    private renderStuck;
    constructor();
    componentWillLoad(): void;
    componentDidLoad(): void;
    disconnectedCallback(): void;
    render(): HTMLZAppHeaderElement;
}
