import { EventEmitter } from "../../stencil-public-runtime";
/**
 * A component to create submenus inside the ZMenu.
 * @slot - Label of the menu section.
 * @slot section - Single entry of the menu section. Set the same slot name to different elements to put many of them. Add the `data-active` attribute to a slotted element to highlight it (`active` also works but `data-active` is preferable).
 */
export declare class ZMenuSection {
    host: HTMLZMenuSectionElement;
    /** Active state */
    active?: boolean;
    /**
     * Tabindex value to set on the label button.
     * Useful to manage keyboard navigation focus with roving tabindex handled by this component's parent (usually ZMenu).
     */
    htmlTabindex: number;
    /** The opening state of the section. */
    open: boolean;
    hasItems: boolean;
    items: HTMLElement[];
    /** The section has been opened. */
    opened: EventEmitter;
    /** The section has been closed. */
    closed: EventEmitter;
    private label;
    private get focusableItem();
    private toggle;
    private setItemsA11yAttrs;
    private onItemsChange;
    /**
     * Sets slotted item text as `data-text` attribute value, to let CSS use it through `attr()`.
     * @param ev Slotchange event
     */
    private onLabelSlotChange;
    private onLabelClick;
    private onLabelKeydown;
    /**
     * Move focus and adjust the tabindex value of `receiver` and `current` elements,
     * setting -1 to the `current` and 0 to the `receiver`, then focus the `receiver` element.
     */
    private moveFocus;
    private focustFirstItem;
    /** Focus the last item. */
    focusLastItem(): Promise<void>;
    /** Set tabindex of the label to 0, then focus it. */
    setFocus(): Promise<void>;
    onOpenChange(): void;
    onTabindexChange(): void;
    private onItemsKeydown;
    constructor();
    connectedCallback(): void;
    render(): HTMLZMenuSectionElement;
}
