import { EventEmitter } from "../../stencil-public-runtime";
import { OffCanvasVariant, TransitionDirection } from "../../beans";
/**
 * @slot canvasContent - Slot for the offcanvas content.
 * @cssprop --z-offcanvas--top-space - Top offset of the offcanvas, for `overlay` variant. Useful when there is some fixed element above the offcanvas. Default: `0`.
 * @cssprop --z-offcanvas--container-width - Width of the offcanvas for `left` and `right` direction. Default: `375px`.
 * @cssprop --z-offcanvas--container-height - Height of the offcanvas for `up` direction. Default: `90%`.
 */
export declare class ZOffcanvas {
    /**
     * Offcanvas variant.
     * - `overlay`: The offcanvas covers the page content putting an overlay.
     * - `pushcontent`: The offcanvas isn't absolutely positioned and "pushes" the page content.
     * > NB: `pushcontent` variant may need some extra style tuning of the context around the component to work properly.
     * Also, the `pushcontent` variant doesn't have the open/close transition.
     */
    variant?: OffCanvasVariant;
    /** Whether the offcanvas is open. Default: false */
    open: boolean;
    /**
     * Open the content transitioning to a specified direction.
     * The `up` direction always show the `overlay`, also when the variant is `pushcontent`.
     */
    transitiondirection?: TransitionDirection;
    /**
     * Skip the opening transition when the offcanvas is already open at the first render.
     * @deprecated This prop is not needed anymore, the component will automatically skip the transition
     *  when it starts with `open` set to `true`. Only exists for Typescript backward compatibility.
     */
    skipLoadAnimation: boolean;
    /** emitted when `open` prop changes */
    canvasOpenStatusChanged: EventEmitter;
    /** Used to skip the opening transition when the offcanvas is already open at the first render. */
    private skipAnimation;
    private canvasContainer;
    /**
     * Stop the event default behavior and propagation when the offcanvas is closed.
     */
    stopEvent(event: Event): void;
    /**
     * Hide the body overflow when the offcanvas is open.
     */
    private handlePageOverflow;
    onOpenChanged(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    componentDidRender(): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    render(): HTMLZOffcanvasElement;
}
