import "./index.stories.css";
/**
 * The typographic styles are based on the `IBM Plex` font family.
 * Some CSS classes and props are provided to apply the typographic styles:
 * - a set of CSS custom props for font sizes and font weights
 * - a set of classes for headings, body text, and interactive text
 * - a set of classes and CSS custom props for section titles
 */
declare const _default: {
    title: string;
    argTypes: {
        fontFamily: {
            options: string[];
            control: {
                type: "inline-radio";
            };
        };
    };
    args: {
        fontFamily: string;
    };
};
export default _default;
export declare const TypeScale: {
    parameters: {
        docs: {
            story: {
                inline: boolean;
                height: string;
            };
        };
    };
    argTypes: {
        fontWeight: {
            options: string[];
            control: {
                type: "inline-radio";
            };
        };
    };
    args: {
        fontWeight: string;
    };
    render: (args: import("@storybook/csf").Args) => import("lit-html").TemplateResult<1>;
};
/**
 * `.heading-1` and `.heading-2` classes automatically scale in size starting from desktop viewport.
 * Typography classes (except for `helper`) can also be used with a viewport prefix (`mobile`, `tablet`, `desktop`, `wide`)
 * to apply the styles only on specific viewport sizes.
 * For example:
 *
 * ```
 * <p class="mobile-body-3 tablet-body-2 body-1">Lorem ipsum...</p>
 * ```
 *
 * will apply the `body-3` style on mobile, `body-2` on tablet, and `body-1` on desktop and wide viewports.
 *
 * Section titles are also available as CSS custom properties:
 * those properties are meant to be used with the "font" shorthand property. For example:
 *
 * ```
 * h4 {
 *  font: var(--section-title-4);
 * }
 * ```
 */
export declare const TypographyClasses: {
    argTypes: {
        headingWeight: {
            options: string[];
            control: {
                type: "inline-radio";
                labels: {
                    lt: string;
                    null: string;
                    sb: string;
                };
            };
        };
        fontWeight: {
            options: string[];
            control: {
                type: "inline-radio";
                labels: {
                    null: string;
                    sb: string;
                };
            };
        };
    };
    args: {
        headingWeight: any;
        fontWeight: any;
    };
    render: (args: import("@storybook/csf").Args) => import("lit-html").TemplateResult<1>;
};
